ALTER TABLE disciplines
    ADD COLUMN isglobalstub bool;

ALTER TABLE disciplines
    ALTER COLUMN isglobalstub set default FALSE;

UPDATE disciplines SET isglobalstub = FALSE;

DROP FUNCTION IF EXISTS public.discipline_setstub(pdisciplineid integer);
CREATE OR REPLACE FUNCTION public.discipline_setstub(pdisciplineid integer)
    RETURNS integer
    LANGUAGE plpgsql
AS $function$
BEGIN

    UPDATE disciplines SET isglobalstub=TRUE
    WHERE disciplines.id = pdisciplineid;

    RETURN 0;
EXCEPTION
    when others
        then RETURN -1;
end
$function$;

DROP FUNCTION IF EXISTS public.discipline_setnotstub(pdisciplineid integer);
CREATE OR REPLACE FUNCTION public.discipline_setnotstub(pdisciplineid integer)
    RETURNS integer
    LANGUAGE plpgsql
AS $function$
BEGIN

    UPDATE disciplines SET isglobalstub=FALSE
    WHERE disciplines.id = pdisciplineid;

    RETURN 0;
EXCEPTION
    when others
        then RETURN -1;
end
$function$;

DROP VIEW IF EXISTS public.view_disciplines;

CREATE OR REPLACE VIEW public.view_disciplines
AS SELECT DISTINCT ON (disciplines.id) disciplines.id AS disciplineid,
                                       disciplines.authorid,
                                       disciplines.examtype,
                                       disciplines.lecturecount,
                                       disciplines.practicecount,
                                       disciplines.labcount,
                                       disciplines.semesterid,
                                       disciplines.islocked,
                                       disciplines.milestone,
                                       disciplines.subtype,
                                       disciplines.compounddiscid,
                                       disciplines.maxrate,
                                       disciplines.currate,
                                       disciplines.isinactive,
                                       disciplines.isglobal,
                                       disciplines.isglobalstub,
                                       grades.id AS gradeid,
                                       grades.num AS gradenum,
                                       grades.degree,
                                       subjects.id AS subjectid,
                                       subjects.name AS subjectname,
                                       subjects.abbr AS subjectabbr,
                                       faculties.id AS facultyid,
                                       faculties.name AS facultyname,
                                       faculties.abbr AS facultyabbr,
                                       compound_disciplines.name AS compounddiscname,
                                       global_disciplines.name AS globalname,
                                       study_plans.externalid AS planexternalid
   FROM disciplines
            JOIN subjects ON subjects.id = disciplines.subjectid
            JOIN faculties ON faculties.id = disciplines.facultyid
            LEFT JOIN grades ON grades.id = disciplines.gradeid
            LEFT JOIN compound_disciplines ON compound_disciplines.id = disciplines.compounddiscid
            LEFT JOIN disciplines_study_plans ON disciplines_study_plans.disciplineid = disciplines.id
            LEFT JOIN study_plans ON study_plans.id = disciplines_study_plans.studyplanid
            LEFT JOIN global_disciplines ON global_disciplines.disciplineid = disciplines.id;

drop function if exists public.discipline_getinfo(pdisciplineid integer);
CREATE OR REPLACE FUNCTION public.discipline_getinfo(pdisciplineid integer)
    RETURNS TABLE("ID" integer, "AuthorID" integer, "GradeID" integer, "GradeNum" integer, "Degree" bachelor_master_specialist, "Type" exam_credit_grading_credit, "Lectures" integer, "Practice" integer, "Labs" integer, "SemesterID" integer, "SubjectID" integer, "SubjectName" character varying, "SubjectAbbr" character varying, "FacultyID" integer, "FacultyName" character varying, "IsLocked" integer, "Milestone" integer, "Subtype" scientific_disciplinary_coursework, "CompoundDiscID" integer, "IsMapCreated" boolean, "IsGlobal" boolean, "IsGlobalStub" boolean, "IsBonus" boolean, "semesterNum" integer, "semesterYear" integer, "IsInactive" boolean, "GlobalName" character varying)
    LANGUAGE plpgsql
AS $function$
DECLARE vIsBonus BOOLEAN;
begin
    --	select * from public.discipline_getinfo(
--	:pdisciplineid 	-- put the pdisciplineid parameter value instead of 'pdisciplineid' (int4)
--);
    vIsBonus := EXISTS(
            SELECT * FROM modules
            WHERE   modules.DisciplineID = pDisciplineID AND
                    modules.Type = 'bonus'
            LIMIT 1
        );
    return query
        SELECT
            view_disciplines.DisciplineID AS "ID",
            view_disciplines.AuthorID as "AuthorID",
            view_disciplines.GradeID as "GradeID",
            view_disciplines.GradeNum as "GradeNum",
            view_disciplines."degree" as "Degree",
            view_disciplines.ExamType       AS "Type",
            view_disciplines.LectureCount   AS "Lectures",
            view_disciplines.PracticeCount  AS "Practice",
            view_disciplines.LabCount       AS "Labs",
            view_disciplines.SemesterID as "SemesterID",
            view_disciplines.SubjectID as "SubjectID",
            view_disciplines.SubjectName as "SubjectName",
            view_disciplines.SubjectAbbr as "SubjectAbbr",
            view_disciplines.FacultyID as "FacultyID",
            view_disciplines.FacultyName as "FacultyName",
            view_disciplines.IsLocked as "IsLocked",
            view_disciplines.Milestone as "Milestone",
            view_disciplines.Subtype as "Subtype",
            view_disciplines.CompoundDiscID as "CompoundDiscID",
            (view_disciplines.MaxRate = 100) AS "IsMapCreated",
            --NOT EXISTS (SELECT disciplines_study_plans.id from disciplines_study_plans WHERE disciplines_study_plans.DisciplineID = view_disciplines.DisciplineID) AS "IsGlobal",
            view_disciplines.IsGlobal AS "IsGlobal",
            view_disciplines.IsGlobalStub AS "IsGlobalStub",
            vIsBonus AS "IsBonus",
            semesters.Num AS "semesterNum", -- TODO: Camelize
            semesters.Year AS "semesterYear",
            view_disciplines.IsInactive as "IsInactive",
            view_disciplines.GlobalName AS "GlobalName"
        FROM view_disciplines
                 INNER JOIN semesters ON semesters.ID = view_disciplines.SemesterID
        WHERE view_disciplines.DisciplineID = pDisciplineID
        LIMIT 1;
END ;
$function$;

drop function if exists public.getdisciplinesforteacher(pteacherid integer, psemesterid integer);
CREATE OR REPLACE FUNCTION public.getdisciplinesforteacher(pteacherid integer, psemesterid integer)
    RETURNS TABLE("ID" integer, "Type" exam_credit_grading_credit, "SubType" scientific_disciplinary_coursework, "GradeID" integer, "GradeNum" integer, "Degree" bachelor_master_specialist, "GroupID" integer, "GroupNum" integer, "GroupName" character varying, "SubjectID" integer, "SubjectName" character varying, "AuthorID" integer, "IsLocked" integer, "IsMapCreated" boolean, "IsGlobal" boolean, "IsGlobalStub" boolean, "GlobalName" character varying)
    LANGUAGE sql
AS $function$
    --select public.getdisciplinesforteacher(
--	:pteacherid,	-- put the pteacherid parameter value instead of 'pteacherid' (int4)
--	:psemesterid 	-- put the psemesterid parameter value instead of 'psemesterid' (int4)
--);
SELECT DISTINCT view_disciplines.DisciplineID AS "ID",
                view_disciplines.ExamType AS "Type",
                view_disciplines.Subtype as "SubType",
                view_disciplines.GradeID as "GradeID",
                view_disciplines.GradeNum as "GradeNum",
                view_disciplines."degree" as "Degree",
                view_groups.GroupID as "GroupID",
                view_groups.GroupNum as "GroupNum",
                view_groups.GroupName as "GroupName",
                view_disciplines.SubjectID as "SubjectID",
                view_disciplines.SubjectName as "SubjectName",
                view_disciplines.AuthorID as "AuthorID",
                view_disciplines.IsLocked AS "IsLocked", -- bodging, db schema remembered lowerCase
                (view_disciplines.MaxRate = 100)    AS "IsMapCreated",
                --NOT EXISTS (SELECT disciplines_study_plans.id from disciplines_study_plans WHERE disciplines_study_plans.DisciplineID = view_disciplines.DisciplineID) AS "IsGlobal"
                view_disciplines.IsGlobal AS "IsGlobal",
                view_disciplines.IsGlobalStub AS "IsGlobalStub",
                view_disciplines.GlobalName AS "GlobalName"
FROM disciplines_teachers
         INNER JOIN view_disciplines ON disciplines_teachers.DisciplineID = view_disciplines.DisciplineID
         INNER JOIN semesters ON semesters.ID = view_disciplines.SemesterID
         LEFT JOIN disciplines_groups ON disciplines_groups.DisciplineID = disciplines_teachers.DisciplineID
         LEFT JOIN view_groups ON view_groups.GroupID = disciplines_groups.GroupID AND view_groups.Year = semesters.Year
WHERE disciplines_teachers.TeacherID = pTeacherID AND view_disciplines.SemesterID = pSemesterID AND view_disciplines.IsInactive = FALSE AND view_disciplines.IsGlobalStub = FALSE
ORDER BY    view_disciplines.GradeID ASC,
            view_disciplines.SubjectName ASC,
            view_disciplines.DisciplineID ASC,
            view_groups.GroupNum ASC;
$function$;

drop function if exists public.getdisciplinesforgroup(pgroupid integer, psemesterid integer, pshowglobal boolean, pshowhidden boolean);
drop function if exists public.getdisciplinesforgroup(pgroupid integer, psemesterid integer, pshowglobal boolean, pshowstubs boolean, pshowhidden boolean);
CREATE OR REPLACE FUNCTION public.getdisciplinesforgroup(pgroupid integer, psemesterid integer, pshowglobal boolean DEFAULT false, pshowstubs boolean DEFAULT false, pshowhidden boolean DEFAULT false)
    RETURNS TABLE("ID" integer, "SubjectID" integer, "SubjectName" character varying, "Subtype" scientific_disciplinary_coursework, "Type" exam_credit_grading_credit, "CompoundDiscID" integer, "CompoundDiscName" character varying, "CurRate" integer, "MaxRate" integer, "IsGlobal" boolean, "IsGlobalStub" boolean, "IsInactive" boolean, "GlobalName" character varying)
    LANGUAGE plpgsql
AS $function$
BEGIN
    return query
        SELECT DISTINCT view_disciplines.DisciplineID AS "ID",
                        view_disciplines.subjectid as "SubjectID",
                        view_disciplines.SubjectName as "SubjectName",
                        view_disciplines.Subtype as "Subtype",
                        view_disciplines.ExamType  AS "Type",
                        view_disciplines.CompoundDiscID as "CompoundDiscID",
                        view_disciplines.CompoundDiscName as "CompoundDiscName",
                        view_disciplines.CurRate as "CurRate",
                        view_disciplines.MaxRate as "MaxRate",
                        view_disciplines.isGlobal as "IsGlobal",
                        view_disciplines.isGlobalStub as "IsGlobalStub",
                        view_disciplines.isInactive as "IsInactive",
                        global_disciplines.name as "GlobalName"
        FROM students_groups
                 LEFT JOIN view_disciplines_recordbooks ON students_groups.RecordBookID = view_disciplines_recordbooks.RecordBookID
                 INNER JOIN view_disciplines ON view_disciplines_recordbooks.DisciplineID = view_disciplines.DisciplineID
                 LEFT JOIN global_disciplines ON view_disciplines.DisciplineID = global_disciplines.disciplineid
        WHERE   students_groups.GroupID = pGroupID AND
                students_groups.SemesterID = pSemesterID AND
                view_disciplines.SemesterID = pSemesterID AND
            (NOT (view_disciplines.IsInactive) OR pshowhidden) AND
            (NOT (view_disciplines.IsGlobal) OR pshowglobal) AND
            (NOT (view_disciplines.IsGlobalStub) OR pshowstubs) AND
                students_groups.State <= 'outlet' AND
          -- view_disciplines_recordbooks.Type may be attach or NULL
                COALESCE(view_disciplines_recordbooks.Type, 'attach') = 'attach'
        ORDER BY view_disciplines.ExamType DESC,
                 view_disciplines.SubjectName ASC;
end;
$function$;

DROP VIEW IF EXISTS public.view_global_final_report;
CREATE OR REPLACE VIEW public.view_global_final_report
AS SELECT DISTINCT semesters.year AS semesteryear,
                   semesters.num AS semesternum,
                   study_plans.externalid AS planexternalid,
                   subjects.externalid AS subjectexternalid,
                   record_books.externalid AS recordbookexternalid,
                   gd.examtype,
                   ( SELECT sum(rating_table.rate) AS sum
                     FROM rating_table
                              JOIN submodules ON rating_table.submoduleid = submodules.id
                              JOIN modules ON submodules.moduleid = modules.id
                     WHERE modules.disciplineid = gd.id AND modules.type = 'regular'::regular_exam_bonus_extra AND rating_table.recordbookid = record_books.id
                     GROUP BY modules.disciplineid, rating_table.recordbookid) AS semesterrate,
                   ( SELECT
                         CASE
                             WHEN rt.rate IS NOT NULL THEN rt.rate
                             WHEN rt.rate IS NULL THEN
                                 CASE epo.type
                                     WHEN 'pass'::absence_pass THEN '-2'::integer
                                     WHEN 'absence'::absence_pass THEN '-1'::integer
                                     ELSE NULL::integer
                                     END
                             ELSE NULL::integer
                             END AS rate
                     FROM view_roadmap vr
                              LEFT JOIN rating_table rt ON vr.submoduleid = rt.submoduleid AND rt.recordbookid = record_books.id
                              LEFT JOIN exam_period_options epo ON epo.submoduleid = vr.submoduleid AND epo.recordbookid = record_books.id
                     WHERE vr.disciplineid = gd.id AND vr.moduletype = 'exam'::regular_exam_bonus_extra
                     ORDER BY vr.moduletype, vr.moduleordernum, vr.submoduleordernum
                     LIMIT 1) AS examrate,
                   ( SELECT
                         CASE
                             WHEN rt.rate IS NOT NULL THEN rt.rate
                             WHEN rt.rate IS NULL THEN
                                 CASE epo.type
                                     WHEN 'pass'::absence_pass THEN 0
                                     WHEN 'absence'::absence_pass THEN '-1'::integer
                                     ELSE NULL::integer
                                     END
                             ELSE NULL::integer
                             END AS rate
                     FROM view_roadmap vr
                              LEFT JOIN rating_table rt ON vr.submoduleid = rt.submoduleid AND rt.recordbookid = record_books.id
                              LEFT JOIN exam_period_options epo ON epo.submoduleid = vr.submoduleid AND epo.recordbookid = record_books.id
                     WHERE vr.disciplineid = gd.id AND vr.moduletype = 'exam'::regular_exam_bonus_extra
                     ORDER BY vr.moduletype, vr.moduleordernum, vr.submoduleordernum
                         OFFSET 1
                     LIMIT 1) AS exam2rate,
                   ( SELECT
                         CASE
                             WHEN rt.rate IS NOT NULL THEN rt.rate
                             WHEN rt.rate IS NULL THEN
                                 CASE epo.type
                                     WHEN 'pass'::absence_pass THEN 0
                                     WHEN 'absence'::absence_pass THEN '-1'::integer
                                     ELSE NULL::integer
                                     END
                             ELSE NULL::integer
                             END AS rate
                     FROM view_roadmap vr
                              LEFT JOIN rating_table rt ON vr.submoduleid = rt.submoduleid AND rt.recordbookid = record_books.id
                              LEFT JOIN exam_period_options epo ON epo.submoduleid = vr.submoduleid AND epo.recordbookid = record_books.id
                     WHERE vr.disciplineid = gd.id AND vr.moduletype = 'exam'::regular_exam_bonus_extra
                     ORDER BY vr.moduletype, vr.moduleordernum, vr.submoduleordernum
                         OFFSET 2
                     LIMIT 1) AS exam3rate,
                   ( SELECT rating_table.rate
                     FROM rating_table
                              JOIN submodules ON rating_table.submoduleid = submodules.id
                              JOIN modules ON submodules.moduleid = modules.id
                     WHERE modules.disciplineid = gd.id AND modules.type = 'extra'::regular_exam_bonus_extra AND rating_table.recordbookid = record_books.id
                     ORDER BY submodules.ordernum
                     LIMIT 1) AS extrarate,
                   ( SELECT rating_table.rate
                     FROM rating_table
                              JOIN submodules ON rating_table.submoduleid = submodules.id
                              JOIN modules ON submodules.moduleid = modules.id
                     WHERE modules.disciplineid = gd.id AND modules.type = 'extra'::regular_exam_bonus_extra AND rating_table.recordbookid = record_books.id
                     ORDER BY submodules.ordernum
                         OFFSET 1
                     LIMIT 1) AS extra2rate,
                   ( SELECT rating_table.rate
                     FROM rating_table
                              JOIN submodules ON rating_table.submoduleid = submodules.id
                              JOIN modules ON submodules.moduleid = modules.id
                     WHERE modules.disciplineid = gd.id AND modules.type = 'bonus'::regular_exam_bonus_extra AND rating_table.recordbookid = record_books.id
                     LIMIT 1) AS bonusrate
   FROM global_disciplines
            JOIN semesters ON global_disciplines.semesterid = semesters.id
            JOIN disciplines gd ON gd.id = global_disciplines.disciplineid
            JOIN disciplines_students ON gd.id = disciplines_students.disciplineid AND disciplines_students.type = 'attach'::attach_detach
            JOIN subjects ON subjects.id = gd.subjectid
            JOIN disciplines ld ON ld.subjectid = gd.subjectid AND ld.semesterid = gd.semesterid AND ld.isglobal = false AND ld.isglobalstub = true -- AND ld.isinactive = true
            JOIN disciplines_study_plans ON disciplines_study_plans.disciplineid = ld.id
            JOIN study_plans ON study_plans.id = disciplines_study_plans.studyplanid
            JOIN view_disciplines_recordbooks ON view_disciplines_recordbooks.disciplineid = ld.id AND 'attach'::attach_detach = COALESCE(view_disciplines_recordbooks.type, 'attach'::attach_detach)
            JOIN record_books ON record_books.id = view_disciplines_recordbooks.recordbookid AND record_books.id = disciplines_students.recordbookid
            JOIN record_books_plans ON record_books.id = record_books_plans.recordbookid AND record_books_plans.studyplanid = study_plans.id;

DROP FUNCTION IF EXISTS public.getdisciplinesforexport(pgroupid integer, psemesterid integer);
CREATE OR REPLACE FUNCTION public.getdisciplinesforexport(pgroupid integer, psemesterid integer)
    RETURNS TABLE("ID" integer, "SubjectName" character varying, "DisciplineExternalID" character varying, "PlanExternalID" integer)
    LANGUAGE plpgsql
AS $function$
BEGIN
    return query
        select D."ID" as "ID",
               D."SubjectName" as "SubjectName",
               subjects.externalid as "DisciplineExternalID",
               study_plans.externalid as "PlanExternalID"
        from public.getdisciplinesforgroup(pgroupid, psemesterid, True, True, True) as D
                 join disciplines on disciplines.id = D."ID"
                 join subjects on disciplines.subjectid = subjects.id
                 join disciplines_study_plans on disciplines_study_plans.disciplineid = D."ID"
                 join students_groups on public.students_groups.groupid = pgroupid
                 join record_books_plans on record_books_plans.recordbookid = public.students_groups.recordbookid
                 join study_plans on disciplines_study_plans.studyplanid = study_plans.id and record_books_plans.studyplanid = study_plans.id
        where (D."IsGlobalStub" = true) or (D."IsInactive" = false and D."IsGlobalStub" = false and D."IsGlobal" = false);
    --where (D."IsInactive" = true and D."IsGlobal" = true) or (D."IsInactive" = false and D."IsGlobal" = false);
end;
$function$;

DROP VIEW IF EXISTS view_disciplines_stat;

DROP FUNCTION IF EXISTS public.disciplinecollection_full(psemesterid integer, pfacultyid integer);
CREATE OR REPLACE FUNCTION public.disciplinecollection_full(psemesterid integer, pfacultyid integer)
    RETURNS TABLE("ID" integer, "SubjectName" character varying, "AuthorID" integer, "FacultyName" character varying, "GradeNum" integer, "ExamType" exam_credit_grading_credit, "State" text, "IsInactive" boolean, "IsGlobal" boolean, "IsGlobalStub" boolean, "GlobalName" character varying)
    LANGUAGE plpgsql
AS $function$
    -- select public.discipline_getwithfullness(
--	:psemesterid,	-- put the psemesterid parameter value instead of 'psemesterid' (int4)
--	:pfacultyid 	-- put the pfacultyid parameter value instead of 'pfacultyid' (int4)
-- );
BEGIN
    return query
        SELECT view_disciplines.DisciplineID AS ID,
               view_disciplines.SubjectName As SubjectName,
               view_disciplines.AuthorID As AuthorID,
               view_disciplines.facultyname as FacultyName,
               view_disciplines.gradenum as GradeNum,
               view_disciplines.examtype as ExamType,
               CASE
                   WHEN (view_disciplines.MaxRate < 100 AND view_disciplines.IsLocked = 0) THEN 'no_map'
                   WHEN (view_disciplines.MaxRate = 100 AND view_disciplines.IsLocked = 0) THEN 'no_rates'
                   WHEN (view_disciplines.MaxRate = 100 AND view_disciplines.IsLocked = 1) THEN 'in_progress'
                   ELSE 'other'
                   END AS State,
               view_disciplines.IsInactive as IsInactive,
               view_disciplines.isglobal,
               view_disciplines.isglobalstub,
               view_disciplines.globalname
        FROM view_disciplines
                 JOIN disciplines ON view_disciplines.disciplineid = disciplines.id
        WHERE view_disciplines.SemesterID = pSemesterID AND
                view_disciplines.FacultyID = pFacultyID;
END
$function$;

DROP FUNCTION IF EXISTS public.disciplinecollection_get(psemesterid integer, pfacultyid integer, pgradenum integer, pdegree bachelor_master_specialist);
CREATE OR REPLACE FUNCTION public.disciplinecollection_get(psemesterid integer, pfacultyid integer, pgradenum integer DEFAULT NULL::integer, pdegree bachelor_master_specialist DEFAULT NULL::bachelor_master_specialist)
    RETURNS TABLE("ID" integer, "SubjectName" character varying, "AuthorID" integer, "State" text, "IsInactive" boolean, "IsGlobalStub" boolean, "PlanExternalID" integer, "GlobalName" character varying)
    LANGUAGE plpgsql
AS $function$
    -- select public.discipline_getwithfullness(
--	:psemesterid,	-- put the psemesterid parameter value instead of 'psemesterid' (int4)
--	:pfacultyid 	-- put the pfacultyid parameter value instead of 'pfacultyid' (int4)
-- );
BEGIN
    return query
        SELECT view_disciplines.DisciplineID AS ID,
               view_disciplines.SubjectName As SubjectName,
               view_disciplines.AuthorID As AuthorID,
               CASE
                   WHEN (view_disciplines.MaxRate < 100 AND view_disciplines.IsLocked = 0) THEN 'no_map'
                   WHEN (view_disciplines.MaxRate = 100 AND view_disciplines.IsLocked = 0) THEN 'no_rates'
                   WHEN (view_disciplines.MaxRate = 100 AND view_disciplines.IsLocked = 1) THEN 'in_progress'
                   ELSE 'other'
                   END AS State,
               disciplines.IsInactive as IsInactive,
               disciplines.IsGlobalStub as IsGlobalStub,
               view_disciplines.planexternalid,
               view_disciplines.globalname as GlobalName
        FROM view_disciplines
                 JOIN disciplines ON view_disciplines.disciplineid = disciplines.id
        WHERE view_disciplines.SemesterID = pSemesterID AND
                view_disciplines.FacultyID = pFacultyID AND
            (view_disciplines.GradeNum = pgradenum or ((public.view_disciplines.GradeNum = pgradenum)is unknown)) AND
            (view_disciplines.Degree = pdegree or ((public.view_disciplines.Degree = pdegree)is unknown));
END
$function$;

CREATE OR REPLACE VIEW public.view_disciplines_stat
AS SELECT ff.name,
          ( SELECT count(*) AS count
            FROM disciplinecollection_get(11, ff.id) disciplinecollection_get("ID", "SubjectName", "AuthorID", "State", "IsInactive", "PlanExternalID", "GlobalName")) AS "Всего дисциплин",
          ( SELECT count(*) AS count
            FROM disciplinecollection_get(11, ff.id) t("ID", "SubjectName", "AuthorID", "State", "IsInactive", "PlanExternalID", "GlobalName")
            WHERE t."State" = 'no_map'::text AND t."IsInactive" = false) AS "Без УКД"
   FROM faculties ff;


--- extra patch:
-- UPDATE disciplines SET isglobal=false, isglobalstub=true, isinactive=true
-- WHERE disciplines.isglobal=true and disciplines.isinactive=true
